==> ejc-probudget-impl-3.0.0-20210906.101225-5-sources.jar: com/ejianc/business/plan/bean/BudgetPlanEntity.java <==
package com.ejianc.business.plan.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工计划
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probudget_plan")
public class BudgetPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="budget_id")
    private Long budgetId; // 预算id
    @TableField(value="income_budget_mny")
    private java.math.BigDecimal incomeBudgetMny; // 收入预算金额
    @TableField(value="cost_budget_mny")
    private java.math.BigDecimal costBudgetMny; // 成本预算金额
    @TableField(value="labor_mny")
    private java.math.BigDecimal laborMny; // 人工费
    @TableField(value="material_mny")
    private java.math.BigDecimal materialMny; // 材料费
    @TableField(value="manage_mny")
    private java.math.BigDecimal manageMny; // 管理费
    @TableField(value="area_id")
    private Long areaId; // 区域id
    @TableField(value="area_name")
    private String areaName; // 区域名称
    @TableField(value="start_month")
    private String startMonth; // 开始月份
    @TableField(value="end_month")
    private String endMonth; // 结束月份
    @TableField(value="month_end_date")
    private java.util.Date monthEndDate; // 每月截止日期
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    
    
    

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 预算id
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 预算id
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 收入预算金额
     */
    public java.math.BigDecimal getIncomeBudgetMny() {
        return incomeBudgetMny;
    }

    /**
     * 收入预算金额
     */
    public void setIncomeBudgetMny(java.math.BigDecimal incomeBudgetMny) {
        this.incomeBudgetMny = incomeBudgetMny;
    }
    /**
     * 成本预算金额
     */
    public java.math.BigDecimal getCostBudgetMny() {
        return costBudgetMny;
    }

    /**
     * 成本预算金额
     */
    public void setCostBudgetMny(java.math.BigDecimal costBudgetMny) {
        this.costBudgetMny = costBudgetMny;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborMny() {
        return laborMny;
    }

    /**
     * 人工费
     */
    public void setLaborMny(java.math.BigDecimal laborMny) {
        this.laborMny = laborMny;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialMny() {
        return materialMny;
    }

    /**
     * 材料费
     */
    public void setMaterialMny(java.math.BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    /**
     * 管理费
     */
    public java.math.BigDecimal getManageMny() {
        return manageMny;
    }

    /**
     * 管理费
     */
    public void setManageMny(java.math.BigDecimal manageMny) {
        this.manageMny = manageMny;
    }
    /**
     * 区域id
     */
    public Long getAreaId() {
        return areaId;
    }

    /**
     * 区域id
     */
    public void setAreaId(Long areaId) {
        this.areaId = areaId;
    }
    /**
     * 区域名称
     */
    public String getAreaName() {
        return areaName;
    }

    /**
     * 区域名称
     */
    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    /**
     * 开始月份
     */
    public String getStartMonth() {
        return startMonth;
    }

    /**
     * 开始月份
     */
    public void setStartMonth(String startMonth) {
        this.startMonth = startMonth;
    }
    /**
     * 结束月份
     */
    public String getEndMonth() {
        return endMonth;
    }

    /**
     * 结束月份
     */
    public void setEndMonth(String endMonth) {
        this.endMonth = endMonth;
    }
    /**
     * 每月截止日期
     */
    public java.util.Date getMonthEndDate() {
        return monthEndDate;
    }

    /**
     * 每月截止日期
     */
    public void setMonthEndDate(java.util.Date monthEndDate) {
        this.monthEndDate = monthEndDate;
    }
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    /**
     * 变更单号
     */
    public String getChangeCode() {
        return changeCode;
    }

    /**
     * 变更单号
     */
    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 组织主键
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-probudget-impl-3.0.0-20210913.091414-18-sources.jar: com/ejianc/business/plan/bean/BudgetPlanEntity.java <==
package com.ejianc.business.plan.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 施工计划
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probudget_plan")
public class BudgetPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="budget_id")
    private Long budgetId; // 预算id
    @TableField(value="start_month")
    private String startMonth; // 开始月份
    @TableField(value="end_month")
    private String endMonth; // 结束月份
    @TableField(value="month_end_date")
    private String monthEndDate; // 每月截止日期
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    
    
    

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 预算id
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 预算id
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 开始月份
     */
    public String getStartMonth() {
        return startMonth;
    }

    /**
     * 开始月份
     */
    public void setStartMonth(String startMonth) {
        this.startMonth = startMonth;
    }
    /**
     * 结束月份
     */
    public String getEndMonth() {
        return endMonth;
    }

    /**
     * 结束月份
     */
    public void setEndMonth(String endMonth) {
        this.endMonth = endMonth;
    }
    /**
     * 每月截止日期
     */
    public String getMonthEndDate() {
        return monthEndDate;
    }

    /**
     * 每月截止日期
     */
    public void setMonthEndDate(String monthEndDate) {
        this.monthEndDate = monthEndDate;
    }
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    /**
     * 变更单号
     */
    public String getChangeCode() {
        return changeCode;
    }

    /**
     * 变更单号
     */
    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 组织主键
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}
